@@ -1324,6 +1324,73 @@ act_user_get_password_expiration_policy (ActUser *user,
         }
 }
 
+/**
+ * act_user_set_user_expiration_policy:
+ * @user: the user object to query.
+ * @expiration_time: location to write users expires timestamp
+ *
+ * Set the user expiration policy for a user.
+ *
+ * Note this function is synchronous and ignores errors.
+ **/
+void
+act_user_set_user_expiration_policy (ActUser *user,
+                                     gint64   expiration_time)
+{
+        g_autoptr(GError) error = NULL;
+
+        g_return_if_fail (ACT_IS_USER (user));
+        g_return_if_fail (ACCOUNTS_IS_USER (user->accounts_proxy));
+
+        if (!accounts_user_call_set_user_expiration_policy_sync (user->accounts_proxy,
+                                                                 expiration_time,
+                                                                 G_DBUS_CALL_FLAGS_ALLOW_INTERACTIVE_AUTHORIZATION,
+                                                                 -1,
+                                                                 NULL,
+                                                                 &error)) {
+                g_warning ("SetUserExpirationPolicy call failed: %s", error->message);
+                return;
+        }
+}
+
+/**
+ * act_user_set_password_expiration_policy:
+ * @user: the user object to query.
+ * @min_days_between_changes: location to write minimum number of days needed between password changes.
+ * @max_days_between_changes: location to write maximum number of days password can stay unchanged.
+ * @days_to_warn: location to write number of days to warn user password is about to expire.
+ * @days_after_expiration_until_lock: location to write number of days account will be locked after password expires.
+ *
+ * Set the password expiration policy for a user.
+ *
+ * Note this function is synchronous and ignores errors.
+ **/
+void
+act_user_set_password_expiration_policy (ActUser *user,
+                                         gint64   min_days_between_changes,
+                                         gint64   max_days_between_changes,
+                                         gint64   days_to_warn,
+                                         gint64   days_after_expiration_until_lock)
+{
+        g_autoptr(GError) error = NULL;
+
+        g_return_if_fail (ACT_IS_USER (user));
+        g_return_if_fail (ACCOUNTS_IS_USER (user->accounts_proxy));
+
+        if (!accounts_user_call_set_password_expiration_policy_sync (user->accounts_proxy,
+                                                                     min_days_between_changes,
+                                                                     max_days_between_changes,
+                                                                     days_to_warn,
+                                                                     days_after_expiration_until_lock,
+                                                                     G_DBUS_CALL_FLAGS_ALLOW_INTERACTIVE_AUTHORIZATION,
+                                                                     -1,
+                                                                     NULL,
+                                                                     &error)) {
+                g_warning ("SetPasswordExpirationPolicy call failed: %s", error->message);
+                return;
+        }
+}
+
 /**
  * act_user_set_email:
  * @user: the user object to alter.
